pub struct CompressWriter<W: Write, C: Compressor> { /* private fields */ }Expand description
A writer that compresses data before writing to the inner writer.
Data is buffered and compressed when the buffer is full or when
flush() or finish() is called.
Implementations
Sourceimpl<W: Write, C: Compressor> CompressWriter<W, C>
impl<W: Write, C: Compressor> CompressWriter<W, C>
Sourcepub fn new(inner: W, compressor: C) -> Self
pub fn new(inner: W, compressor: C) -> Self
Create a new compressing writer with default buffer size.
Sourcepub fn with_buffer_size(inner: W, compressor: C, buffer_size: usize) -> Self
pub fn with_buffer_size(inner: W, compressor: C, buffer_size: usize) -> Self
Create a new compressing writer with specified buffer size.
Sourcepub fn compressor(&self) -> &C
pub fn compressor(&self) -> &C
Get a reference to the compressor.